==> org-lsst-sal-camera-2.5.0-sources.jar: org/lsst/sal/camera/event/Image_handling_PeriodicTasks_timersConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Image_handling_PeriodicTasks_timersConfigurationEvent extends CameraEvent {
  private final String version;

  private final long agentmonitorservice_taskPeriodMillis;

  private final long heartbeat_taskPeriodMillis;

  private final long runtimeinfo_taskPeriodMillis;

  public Image_handling_PeriodicTasks_timersConfigurationEvent(int priority, String version,
      long agentmonitorservice_taskPeriodMillis, long heartbeat_taskPeriodMillis,
      long runtimeinfo_taskPeriodMillis) {
    super (priority);
    this.version = version;
    this.agentmonitorservice_taskPeriodMillis = agentmonitorservice_taskPeriodMillis;
    this.heartbeat_taskPeriodMillis = heartbeat_taskPeriodMillis;
    this.runtimeinfo_taskPeriodMillis = runtimeinfo_taskPeriodMillis;
  }

  public String getVersion() {
    return version;
  }

  public long getAgentmonitorservice_taskPeriodMillis() {
    return agentmonitorservice_taskPeriodMillis;
  }

  public long getHeartbeat_taskPeriodMillis() {
    return heartbeat_taskPeriodMillis;
  }

  public long getRuntimeinfo_taskPeriodMillis() {
    return runtimeinfo_taskPeriodMillis;
  }

  @Override
  public String toString() {
    return "Image_handling_PeriodicTasks_timersConfigurationEvent{" + "version=" + version +
        ", agentmonitorservice_taskPeriodMillis=" + agentmonitorservice_taskPeriodMillis +
        ", heartbeat_taskPeriodMillis=" + heartbeat_taskPeriodMillis +
        ", runtimeinfo_taskPeriodMillis=" + runtimeinfo_taskPeriodMillis +"}";
  }
}

==> org-lsst-sal-camera-2.5.8-sources.jar: org/lsst/sal/camera/event/Image_handling_PeriodicTasks_timersConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Image_handling_PeriodicTasks_timersConfigurationEvent extends CameraEvent {
  private final String version;

  private final long agentmonitorservice_taskPeriodMillis;

  private final long heartbeat_taskPeriodMillis;

  private final long runtimeinfo_taskPeriodMillis;

  public Image_handling_PeriodicTasks_timersConfigurationEvent(String version,
      long agentmonitorservice_taskPeriodMillis, long heartbeat_taskPeriodMillis,
      long runtimeinfo_taskPeriodMillis) {
    this.version = version;
    this.agentmonitorservice_taskPeriodMillis = agentmonitorservice_taskPeriodMillis;
    this.heartbeat_taskPeriodMillis = heartbeat_taskPeriodMillis;
    this.runtimeinfo_taskPeriodMillis = runtimeinfo_taskPeriodMillis;
  }

  public String getVersion() {
    return version;
  }

  public long getAgentmonitorservice_taskPeriodMillis() {
    return agentmonitorservice_taskPeriodMillis;
  }

  public long getHeartbeat_taskPeriodMillis() {
    return heartbeat_taskPeriodMillis;
  }

  public long getRuntimeinfo_taskPeriodMillis() {
    return runtimeinfo_taskPeriodMillis;
  }

  @Override
  public String toString() {
    return "Image_handling_PeriodicTasks_timersConfigurationEvent{" + "version=" + version +
        ", agentmonitorservice_taskPeriodMillis=" + agentmonitorservice_taskPeriodMillis +
        ", heartbeat_taskPeriodMillis=" + heartbeat_taskPeriodMillis +
        ", runtimeinfo_taskPeriodMillis=" + runtimeinfo_taskPeriodMillis +"}";
  }
}
